==> haskell-weigh-0.0.18-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 weigh
version:              0.0.18
visibility:           public
id:                   weigh-0.0.18-HNI8IDxNGEBJckxWgn46ZF
key:                  weigh-0.0.18-HNI8IDxNGEBJckxWgn46ZF
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  a4317ea8022d33249a06bd9209896996
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.18-HNI8IDxNGEBJckxWgn46ZF
depends:
    base-4.18.2.1 criterion-measurement-0.2.3.0-378RW5OXLFq5GF7tHz4vZg
    deepseq-1.4.8.1 mtl-2.3.1 process-1.6.19.0
    split-0.2.5-LIo01L9HFTI75RwsLzYVkn
    temporary-1.3-D64vl65CCuJL1VfIJwvdvy

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-weigh-0.0.18-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 weigh
version:              0.0.18
visibility:           public
id:                   weigh-0.0.18-Bvjcnp22nbw80R9LFwFrpF
key:                  weigh-0.0.18-Bvjcnp22nbw80R9LFwFrpF
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  2ff19bb0f2abf53efffde0d19cf80ca1
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.18-Bvjcnp22nbw80R9LFwFrpF
depends:
    base-4.18.2.1 criterion-measurement-0.2.3.0-6IGzRHTPjZ36J46oAMMyxH
    deepseq-1.4.8.1 mtl-2.3.1 process-1.6.19.0
    split-0.2.5-3RnrRTIeHLc8NBcVaUtFqR
    temporary-1.3-BelDM7zTWCg7tBff187Pbn

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
